@@ -1,7 +1,8 @@
 # -*- coding:utf-8; tab-width:4; mode:python -*-
 
-import string
+import sys
 import os
+import string
 import socket
 import traceback
 import logging
@@ -36,17 +37,21 @@ class Interpolator(object):
         ))
 
     def __init__(self):
-        set_testpath()
-        testdir, testname  = os.path.split(gvars.testpath)
-
         self.vars = self.fixed_vars.copy()
+        self.vars.update(gvars.context)
+        set_testpath()
+
+        if not gvars.testpath:
+            print("ERROR: $testdir, $fulltestdir and $testfilename not available in this context")
+            return
+
+        testdir, testname = os.path.split(gvars.testpath)
         self.vars.update(
             dict(
                 testdir      = os.path.relpath(testdir),
                 fulltestdir  = os.path.abspath(testdir),
                 testfilename = testname,
-                ))
-        self.vars.update(gvars.context)
+            ))
 
     def apply(self, text):
         if not isinstance(text, six.string_types):
@@ -121,13 +126,25 @@ def load_default_config(dest):
 
 
 def set_testpath():
+    def is_test_caller(frame):
+        current = "{0.major}.{0.minor}".format(sys.version_info)
+        if current in ['3.5', '3.6', '3.7']:
+            return frame[3] == 'testMethod()'
+
+        return frame[2] == '_callTestMethod'
+
     if gvars.testpath is None:
         return
 
+    _next = False
     it = iter(traceback.extract_stack())
     for frame in it:
-        if frame[3] == 'testMethod()':
-            gvars.testpath = six.next(it)[0]
+        if _next:
+            gvars.testpath = frame[0]
+            return
+
+        if is_test_caller(frame):
+            _next = True
 
 
 def to_text(e):
