@@ -43,7 +43,7 @@ class ContextTests(unittest.TestCase):
         commit()
         self.assertEquals(task.lastcmd.timeout, 3)
 
-    # same as Signals.test_task_is_killed_by_specified_signal
+    # it is the same test as Signals.test_task_is_killed_by_specified_signal
     def test_default_signal(self):
         init()
         context.signal = signal.SIGINT
@@ -55,3 +55,19 @@ class ContextTests(unittest.TestCase):
             self.fail()
         except TestFailed:
             self.assertEquals(cmd.returncode, -signal.SIGINT)
+
+    def test_default_env(self):
+        init()
+        context.env = {'MY_ENV_VAR': '42'}
+        task = Task()
+        task.command('echo $MY_ENV_VAR')
+        task.assert_that(task.lastcmd.stdout.content, contains_string('42'))
+        commit()
+
+    def test_env(self):
+        init()
+        context.env = {'PREGO_SAMPLE': 'hello'}
+        task = Task()
+        task.command('echo $PREGO_SAMPLE')
+        task.assert_that(task.lastcmd.stdout.content, contains_string('hello'))
+        commit()
